dope

package module
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2026 License: BSD-3-Clause Imports: 0 Imported by: 0

README

dope — unapologetically dope

dope is a Go library so undeniably dope your thunks will start aligning with the constellations.

Sometimes the universe aligns perfectly but is this the case today in your life? I wonder. So why use dope anyway?

  1. It's really dope.
  2. Tiny but luxury API, maximal arcane energy.
  3. Unpolished but clean and polite Go that actually helps to survive the hard times.

Docs: https://pkg.go.dev/github.com/marshall-lee/dope

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Is

func Is[T any](val any) bool

Is checks that a value is of a given (generic) type.

func IsEmpty

func IsEmpty[T comparable](val T) bool

IsEmpty checks that a value is equal to an empty value of a given comparable (generic) type.

Types

This section is empty.

Directories

Path Synopsis
bytes
internal
sync

Jump to